require 'common/plugin'

module AgendavPlugin
  # Code that all Agendav plugins (Prune, Rm, Mv...) will
  # share.  That is, we implement the Plugin interface.
  include Plugin


  def initialize(cfg)
    @db_host = cfg.agendav_dbhost
    @db_port = cfg.agendav_dbport
    @db_opts = cfg.agendav_dbopts
    @db_tty  = cfg.agendav_dbtty
    @db_name = cfg.agendav_dbname
    @db_user = cfg.agendav_dbuser
    @db_pass = cfg.agendav_dbpass
  end


  def describe_domain(domain)
    # AgenDAV doesn't have a concept of domains.
    return domain
  end


  def describe_account(account)
    if self.user_exists(account)
      return "Username: #{account}"
    else
      return 'User not found'
    end
  end


  protected;


  def list_users()
    usernames = []

    # Just assume PostgreSQL for now.
    begin
      connection = PGconn.connect(@db_host,
                                  @db_port,
                                  @db_opts,
                                  @db_tty,
                                  @db_name,
                                  @db_user,
                                  @db_pass)

      sql_query  = '(SELECT username FROM prefs)'
      sql_query += 'UNION'
      sql_query += '(SELECT user_from FROM shared);'

      connection.query(sql_query) do |result|
        usernames = result.field_values('username')
      end

      connection.close()
    rescue PGError => e
      # Pretend like we're database-agnostic in case we ever are.
      raise DatabaseError.new(e)
    end

    return usernames
  end

end
